@@ -2,6 +2,13 @@ from django.core.management.base import BaseCommand, CommandError
 from django_thermostat.rules import evaluate
 from time import localtime, strftime
 
+import logging
+from django.conf import settings
+
+
+logger = logging.getLogger("thermostat")
+logger.setLevel(settings.LOG_LEVEL)
+
 
 class Command(BaseCommand):
     args = ''
@@ -9,8 +16,10 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         try:
-            self.stdout.write("Starting at %s" % strftime("%d.%m.%Y %H:%M:%S", localtime()))
+            logger.info("Starting at %s" % strftime("%d.%m.%Y %H:%M:%S", localtime()))
             evaluate()
-            self.stdout.write("Ended at %s" % strftime("%d.%m.%Y %H:%M:%S", localtime()))
-        except Exception, ex:
+            logger.info("Ended at %s" % strftime("%d.%m.%Y %H:%M:%S", localtime()))
+        except Exception as ex:
             self.stderr.write("ERROR: %s" % ex)
+            logger.error("ERROR: %s" % ex)
+
