@@ -1,7 +1,7 @@
 from django_thermostat.models import Context, Thermometer, ThermometerData
 from django.shortcuts import render_to_response, redirect, render
 from django.http import HttpResponse, HttpResponseBadRequest, HttpResponseServerError
-from settings import HEATER_INCREMENT, LIST_THERMOMETERS_API
+from django.conf import settings
 from django.core.urlresolvers import reverse
 from django_thermostat.mappings import get_mappings
 from django_thermometer.temperature import read_temperatures
@@ -10,6 +10,10 @@ from django.db.models import Q
 from django.core.exceptions import ObjectDoesNotExist
 from datetime import datetime, timedelta
 
+logger = logging.getLogger("thermostat")
+logger.setLevel(settings.LOG_LEVEL)
+
+
 def dumy_stats(request):
     return render_to_response(
         "therm/dummy_stats.json",{})
@@ -20,27 +24,25 @@ def temp_data_show(request):
         {}
     )
 
-def temp_data(request, fini=None, ffin=None):
-    
-        if ffin is None:
-            ffin = datetime.now()
-        if fini is None:
-            fini = ffin - timedelta(days=1)
-        data = {}
-        q = ThermometerData.objects.filter(timestamp__gt=fini, timestamp__lt=ffin)
-        print q.query
-        for d in q:
-            print "sacamos, %s, %s" % (d.thermometer, d.timestamp.toordinal())
-            if d.thermometer.caption not in data:
-                data[d.thermometer.caption] = {}
-            data[d.thermometer.caption][d.timestamp.strftime('%s')] = d.value
-        response = HttpResponse(
-            content=simplejson.dumps(data),
-            content_type="application/json")
-        response['Cache-Control'] = 'no-cache'
-        return response
-    #except Exception as et: 
-     #   return HttpResponseServerError("Error loading data: %s" % et)
+def temp_data(request, grouping=None):
+
+    if grouping in (None, "day"):
+        data = ThermometerData.objects.get_last_n_days(3)
+    if grouping == "week":
+        data = ThermometerData.objects.get_last_n_weeks(2)
+    if grouping == "month":
+        data = ThermometerData.objects.get_last_n_months()
+    if grouping == "year":
+        data = ThermometerData.objects.get_last_year()
+
+    response = HttpResponse(
+        content=simplejson.dumps(data),
+        content_type="application/json")
+
+    response['Cache-Control'] = 'no-cache'
+
+    return response
+
 
 def set_external_reference(request, tid):
     try:
@@ -53,7 +55,7 @@ def set_external_reference(request, tid):
         #no previously selected thermostat
         pass
     except Exception as err:
-        logging.error("set_external_reference: %s" % err)
+        logger.error("set_external_reference: %s" % err)
 
     try:
         therm = Thermometer.objects.get(Q(tid=tid) | Q(caption=tid))
@@ -63,9 +65,10 @@ def set_external_reference(request, tid):
     except ObjectDoesNotExist:
         return HttpResponseBadRequest("Thermostats %s not found" % tid)
     except Exception as ex:
-        logging.error("set_external_reference: %s" % ex)
+        logger.error("set_external_reference: %s" % ex)
         return HttpResponseServerError(ex)
 
+
 def set_internal_reference(request, tid):
 
     try:
@@ -75,8 +78,8 @@ def set_internal_reference(request, tid):
         therm.is_internal_reference = None
         therm.save()
     except ObjectDoesNotExist:
-	#no previously selected thermostat
-	pass
+	    #no previously selected thermostat
+	    pass
     except Exception as err:
         logging.error("set_internal_reference: %s" % err)
 
@@ -88,7 +91,7 @@ def set_internal_reference(request, tid):
     except ObjectDoesNotExist:
         return HttpResponseBadRequest("Thermostats %s not found" % tid)
     except Exception as ex:
-        logging.error("set_internal_reference: %s" % ex)
+        logger.error("set_internal_reference: %s" % ex)
         return HttpResponseServerError(ex)
 
 
@@ -103,8 +106,8 @@ def home(request):
 
 
 def temperatures(request):
-    if not LIST_THERMOMETERS_API is None:
-        ret = requests.get("%stemperatures=True" % LIST_THERMOMETERS_API)
+    if not settings.LIST_THERMOMETERS_API is None:
+        ret = requests.get("%stemperatures=True" % settings.LIST_THERMOMETERS_API)
         therms = ret.json()
     else:
         therms = read_temperatures()
@@ -131,9 +134,9 @@ def temperatures(request):
 def dim_temp(request, temp):
     context = Context.objects.get()
     if temp == "confort":
-        context.confort_temperature = float(context.confort_temperature) - float(HEATER_INCREMENT)
+        context.confort_temperature = float(context.confort_temperature) - float(settings.HEATER_INCREMENT)
     if temp == "economic":
-        context.economic_temperature = float(context.economic_temperature) - float(HEATER_INCREMENT)
+        context.economic_temperature = float(context.economic_temperature) - float(settings.HEATER_INCREMENT)
     context.save()
     return redirect(reverse("read_heat_status"))
 
@@ -141,9 +144,9 @@ def dim_temp(request, temp):
 def bri_temp(request, temp):
     context = Context.objects.get()
     if temp == "confort":
-        context.confort_temperature = float(context.confort_temperature) + float(HEATER_INCREMENT)
+        context.confort_temperature = float(context.confort_temperature) + float(settings.HEATER_INCREMENT)
     if temp == "economic":
-        context.economic_temperature = float(context.economic_temperature) + float(HEATER_INCREMENT)
+        context.economic_temperature = float(context.economic_temperature) + float(settings.HEATER_INCREMENT)
     context.save()
     return redirect(reverse("read_heat_status"))
 
@@ -176,5 +179,5 @@ def read_heat_status(request):
 def context_js(request):
     return render_to_response(
         "context.js",
-        {"temperatures_uri": LIST_THERMOMETERS_API, },
+        {"temperatures_uri": settings.LIST_THERMOMETERS_API, },
         content_type="application/javascript")
